// ag-grid-react v27.3.0
import { Context, UserCompDetails } from 'ag-grid-community';
import { MutableRefObject } from 'react';
export declare const showJsComp: (compDetails: UserCompDetails, context: Context, eParent: HTMLElement, ref?: MutableRefObject<any> | ((ref: any) => void)) => () => void;
export declare const createSyncJsComp: (compDetails: UserCompDetails) => any;
