// ag-grid-react v27.3.0
import { RefObject } from 'react';
declare const useReactCommentEffect: (comment: string, eForCommentRef: RefObject<HTMLElement>) => void;
export default useReactCommentEffect;
