import { BeanStub } from "../../context/beanStub";
export declare class DragListenerFeature extends BeanStub {
    private rangeService;
    private dragService;
    private eContainer;
    constructor(eContainer: HTMLElement);
    private postConstruct;
}
