// ag-grid-react v27.3.0
import React from "react";
import { IDetailCellRendererParams } from "ag-grid-community";
declare const _default: React.ForwardRefExoticComponent<IDetailCellRendererParams & React.RefAttributes<unknown>>;
export default _default;
