import { Component } from "../widgets/component";
export declare class FakeHScrollComp extends Component {
    private static TEMPLATE;
    private eLeftSpacer;
    private eRightSpacer;
    private eViewport;
    private eContainer;
    constructor();
    private postConstruct;
}
