// ag-grid-react v27.3.0
import { GroupCellRendererParams } from "ag-grid-community";
import React from 'react';
declare const GroupCellRenderer: React.ForwardRefExoticComponent<GroupCellRendererParams & React.RefAttributes<unknown>>;
export default GroupCellRenderer;
