
// In v23 we moved from using global variables to maps of parameters to configure Grid themes.
// This file is part of a backwards-compatibility layer designed to emulate the pre-v23 behaviour
// and so should not be modified.

$ag-custom-icon-color-defined: global-variable-exists("icon-color") or global-variable-exists("ag-icon-color");

@if (not variable-exists("ag-suppress-legacy-var-import") or not $ag-suppress-legacy-var-import) {
// DO NOT EDIT (see note above)
@if (variable-exists("accent-color") and not variable-exists("ag-accent-color")) {
// DO NOT EDIT (see note above)
    $ag-accent-color: $accent-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("alt-icon-color") and not variable-exists("ag-alt-icon-color")) {
// DO NOT EDIT (see note above)
    $ag-alt-icon-color: $alt-icon-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("background-color") and not variable-exists("ag-background-color")) {
// DO NOT EDIT (see note above)
    $ag-background-color: $background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("border-color") and not variable-exists("ag-border-color")) {
// DO NOT EDIT (see note above)
    $ag-border-color: $border-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("card-radius") and not variable-exists("ag-card-radius")) {
// DO NOT EDIT (see note above)
    $ag-card-radius: $card-radius !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("card-shadow") and not variable-exists("ag-card-shadow")) {
// DO NOT EDIT (see note above)
    $ag-card-shadow: $card-shadow !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("cell-horizontal-border") and not variable-exists("ag-cell-horizontal-border")) {
// DO NOT EDIT (see note above)
    $ag-cell-horizontal-border: $cell-horizontal-border !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("cell-horizontal-padding") and not variable-exists("ag-cell-horizontal-padding")) {
// DO NOT EDIT (see note above)
    $ag-cell-horizontal-padding: $cell-horizontal-padding !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-background-color") and not variable-exists("ag-dialog-background-color")) {
// DO NOT EDIT (see note above)
    $ag-dialog-background-color: $dialog-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-border-color") and not variable-exists("ag-dialog-border-color")) {
// DO NOT EDIT (see note above)
    $ag-dialog-border-color: $dialog-border-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-border-size") and not variable-exists("ag-dialog-border-size")) {
// DO NOT EDIT (see note above)
    $ag-dialog-border-size: $dialog-border-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-border-style") and not variable-exists("ag-dialog-border-style")) {
// DO NOT EDIT (see note above)
    $ag-dialog-border-style: $dialog-border-style !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-background-color") and not variable-exists("ag-dialog-title-background-color")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-background-color: $dialog-title-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-font-family") and not variable-exists("ag-dialog-title-font-family")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-font-family: $dialog-title-font-family !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-font-size") and not variable-exists("ag-dialog-title-font-size")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-font-size: $dialog-title-font-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-font-weight") and not variable-exists("ag-dialog-title-font-weight")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-font-weight: $dialog-title-font-weight !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-foreground-color") and not variable-exists("ag-dialog-title-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-foreground-color: $dialog-title-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-height") and not variable-exists("ag-dialog-title-height")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-height: $dialog-title-height !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-icon-size") and not variable-exists("ag-dialog-title-icon-size")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-icon-size: $dialog-title-icon-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("dialog-title-padding") and not variable-exists("ag-dialog-title-padding")) {
// DO NOT EDIT (see note above)
    $ag-dialog-title-padding: $dialog-title-padding !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("disabled-foreground-color-opacity") and not variable-exists("ag-disabled-foreground-color-opacity")) {
// DO NOT EDIT (see note above)
    $ag-disabled-foreground-color-opacity: $disabled-foreground-color-opacity !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("font-family") and not variable-exists("ag-font-family")) {
// DO NOT EDIT (see note above)
    $ag-font-family: $font-family !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("font-size") and not variable-exists("ag-font-size")) {
// DO NOT EDIT (see note above)
    $ag-font-size: $font-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("font-weight") and not variable-exists("ag-font-weight")) {
// DO NOT EDIT (see note above)
    $ag-font-weight: $font-weight !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("foreground-color") and not variable-exists("ag-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-foreground-color: $foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("foreground-opacity") and not variable-exists("ag-foreground-opacity")) {
// DO NOT EDIT (see note above)
    $ag-foreground-opacity: $foreground-opacity !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("grid-size") and not variable-exists("ag-grid-size")) {
// DO NOT EDIT (see note above)
    $ag-grid-size: $grid-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("group-component-background-color") and not variable-exists("ag-group-component-background-color")) {
// DO NOT EDIT (see note above)
    $ag-group-component-background-color: $group-component-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("group-component-border-color") and not variable-exists("ag-group-component-border-color")) {
// DO NOT EDIT (see note above)
    $ag-group-component-border-color: $group-component-border-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("group-component-title-background-color") and not variable-exists("ag-group-component-title-background-color")) {
// DO NOT EDIT (see note above)
    $ag-group-component-title-background-color: $group-component-title-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-background-color") and not variable-exists("ag-header-background-color")) {
// DO NOT EDIT (see note above)
    $ag-header-background-color: $header-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-cell-moving-background-color") and not variable-exists("ag-header-cell-moving-background-color")) {
// DO NOT EDIT (see note above)
    $ag-header-cell-moving-background-color: $header-cell-moving-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-foreground-color") and not variable-exists("ag-header-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-header-foreground-color: $header-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-height") and not variable-exists("ag-header-height")) {
// DO NOT EDIT (see note above)
    $ag-header-height: $header-height !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-icon-size") and not variable-exists("ag-header-icon-size")) {
// DO NOT EDIT (see note above)
    $ag-header-icon-size: $header-icon-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("icon-color") and not variable-exists("ag-icon-color")) {
// DO NOT EDIT (see note above)
    $ag-icon-color: $icon-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("icon-font-family") and not variable-exists("ag-icon-font-family")) {
// DO NOT EDIT (see note above)
    $ag-icon-font-family: $icon-font-family !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("icon-size") and not variable-exists("ag-icon-size")) {
// DO NOT EDIT (see note above)
    $ag-icon-size: $icon-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("icons-data") and not variable-exists("ag-icons-data")) {
// DO NOT EDIT (see note above)
    $ag-icons-data: $icons-data !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("input-border-color") and not variable-exists("ag-input-border-color")) {
// DO NOT EDIT (see note above)
    $ag-input-border-color: $input-border-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("input-disabled-background-color") and not variable-exists("ag-input-disabled-background-color")) {
// DO NOT EDIT (see note above)
    $ag-input-disabled-background-color: $input-disabled-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("range-selection-background-color") and not variable-exists("ag-range-selection-background-color")) {
// DO NOT EDIT (see note above)
    $ag-range-selection-background-color: $range-selection-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("range-selection-chart-background-color") and not variable-exists("ag-range-selection-chart-background-color")) {
// DO NOT EDIT (see note above)
    $ag-range-selection-chart-background-color: $range-selection-chart-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("range-selection-chart-category-background-color") and not variable-exists("ag-range-selection-chart-category-background-color")) {
// DO NOT EDIT (see note above)
    $ag-range-selection-chart-category-background-color: $range-selection-chart-category-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("rich-select-item-height") and not variable-exists("ag-rich-select-item-height")) {
// DO NOT EDIT (see note above)
    $ag-rich-select-item-height: $rich-select-item-height !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("row-border-width") and not variable-exists("ag-row-border-width")) {
// DO NOT EDIT (see note above)
    $ag-row-border-width: $row-border-width !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("row-group-indent-size") and not variable-exists("ag-row-group-indent-size")) {
// DO NOT EDIT (see note above)
    $ag-row-group-indent-size: $row-group-indent-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("row-height") and not variable-exists("ag-row-height")) {
// DO NOT EDIT (see note above)
    $ag-row-height: $row-height !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("scroll-spacer-border") and not variable-exists("ag-scroll-spacer-border")) {
// DO NOT EDIT (see note above)
    $ag-scroll-spacer-border: $scroll-spacer-border !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-font-family") and not variable-exists("ag-secondary-font-family")) {
// DO NOT EDIT (see note above)
    $ag-secondary-font-family: $secondary-font-family !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-font-size") and not variable-exists("ag-secondary-font-size")) {
// DO NOT EDIT (see note above)
    $ag-secondary-font-size: $secondary-font-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-font-weight") and not variable-exists("ag-secondary-font-weight")) {
// DO NOT EDIT (see note above)
    $ag-secondary-font-weight: $secondary-font-weight !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-foreground-color-opacity") and not variable-exists("ag-secondary-foreground-color-opacity")) {
// DO NOT EDIT (see note above)
    $ag-secondary-foreground-color-opacity: $secondary-foreground-color-opacity !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tool-panel-background-color") and not variable-exists("ag-tool-panel-background-color")) {
// DO NOT EDIT (see note above)
    $ag-tool-panel-background-color: $tool-panel-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("toolpanel-indent-size") and not variable-exists("ag-toolpanel-indent-size")) {
// DO NOT EDIT (see note above)
    $ag-toolpanel-indent-size: $toolpanel-indent-size !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-background-color") and not variable-exists("ag-tooltip-background-color")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-background-color: $tooltip-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-border-color") and not variable-exists("ag-tooltip-border-color")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-border-color: $tooltip-border-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-border-radius") and not variable-exists("ag-tooltip-border-radius")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-border-radius: $tooltip-border-radius !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-border-style") and not variable-exists("ag-tooltip-border-style")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-border-style: $tooltip-border-style !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-border-width") and not variable-exists("ag-tooltip-border-width")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-border-width: $tooltip-border-width !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-foreground-color") and not variable-exists("ag-tooltip-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-foreground-color: $tooltip-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("tooltip-padding") and not variable-exists("ag-tooltip-padding")) {
// DO NOT EDIT (see note above)
    $ag-tooltip-padding: $tooltip-padding !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("transition-speed") and not variable-exists("ag-transition-speed")) {
// DO NOT EDIT (see note above)
    $ag-transition-speed: $transition-speed !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("virtual-item-height") and not variable-exists("ag-virtual-item-height")) {
// DO NOT EDIT (see note above)
    $ag-virtual-item-height: $virtual-item-height !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)
@if (variable-exists("active") and not variable-exists("ag-active")) {
// DO NOT EDIT (see note above)
    $ag-active: $active !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("alt-background") and not variable-exists("ag-alt-background")) {
// DO NOT EDIT (see note above)
    $ag-alt-background: $alt-background !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("border-radius") and not variable-exists("ag-border-radius")) {
// DO NOT EDIT (see note above)
    $ag-border-radius: $border-radius !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("cell-data-changed-color") and not variable-exists("ag-cell-data-changed-color")) {
// DO NOT EDIT (see note above)
    $ag-cell-data-changed-color: $cell-data-changed-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("chip-background-color") and not variable-exists("ag-chip-background-color")) {
// DO NOT EDIT (see note above)
    $ag-chip-background-color: $chip-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("chrome-background") and not variable-exists("ag-chrome-background")) {
// DO NOT EDIT (see note above)
    $ag-chrome-background: $chrome-background !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("default-background") and not variable-exists("ag-default-background")) {
// DO NOT EDIT (see note above)
    $ag-default-background: $default-background !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("disabled-foreground-color") and not variable-exists("ag-disabled-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-disabled-foreground-color: $disabled-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("editor-background-color") and not variable-exists("ag-editor-background-color")) {
// DO NOT EDIT (see note above)
    $ag-editor-background-color: $editor-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-cell-hover-background-color") and not variable-exists("ag-header-cell-hover-background-color")) {
// DO NOT EDIT (see note above)
    $ag-header-cell-hover-background-color: $header-cell-hover-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("hover-color") and not variable-exists("ag-hover-color")) {
// DO NOT EDIT (see note above)
    $ag-hover-color: $hover-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("odd-row-background-color") and not variable-exists("ag-odd-row-background-color")) {
// DO NOT EDIT (see note above)
    $ag-odd-row-background-color: $odd-row-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("panel-background-color") and not variable-exists("ag-panel-background-color")) {
// DO NOT EDIT (see note above)
    $ag-panel-background-color: $panel-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("primary-color") and not variable-exists("ag-primary-color")) {
// DO NOT EDIT (see note above)
    $ag-primary-color: $primary-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("range-selection-highlight-color") and not variable-exists("ag-range-selection-highlight-color")) {
// DO NOT EDIT (see note above)
    $ag-range-selection-highlight-color: $range-selection-highlight-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("row-floating-background-color") and not variable-exists("ag-row-floating-background-color")) {
// DO NOT EDIT (see note above)
    $ag-row-floating-background-color: $row-floating-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("row-stub-background-color") and not variable-exists("ag-row-stub-background-color")) {
// DO NOT EDIT (see note above)
    $ag-row-stub-background-color: $row-stub-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-foreground-color") and not variable-exists("ag-secondary-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-secondary-foreground-color: $secondary-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("selected-color") and not variable-exists("ag-selected-color")) {
// DO NOT EDIT (see note above)
    $ag-selected-color: $selected-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-delta-down-color") and not variable-exists("ag-value-change-delta-down-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-delta-down-color: $value-change-delta-down-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-delta-up-color") and not variable-exists("ag-value-change-delta-up-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-delta-up-color: $value-change-delta-up-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-value-highlight-background-color") and not variable-exists("ag-value-change-value-highlight-background-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-value-highlight-background-color: $value-change-value-highlight-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)
@if (variable-exists("cell-data-changed-color") and not variable-exists("ag-cell-data-changed-color")) {
// DO NOT EDIT (see note above)
    $ag-cell-data-changed-color: $cell-data-changed-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("chip-background-color") and not variable-exists("ag-chip-background-color")) {
// DO NOT EDIT (see note above)
    $ag-chip-background-color: $chip-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("disabled-foreground-color") and not variable-exists("ag-disabled-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-disabled-foreground-color: $disabled-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("editor-background-color") and not variable-exists("ag-editor-background-color")) {
// DO NOT EDIT (see note above)
    $ag-editor-background-color: $editor-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("header-cell-hover-background-color") and not variable-exists("ag-header-cell-hover-background-color")) {
// DO NOT EDIT (see note above)
    $ag-header-cell-hover-background-color: $header-cell-hover-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("hover-color") and not variable-exists("ag-hover-color")) {
// DO NOT EDIT (see note above)
    $ag-hover-color: $hover-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-grey-0") and not variable-exists("ag-mat-grey-0")) {
// DO NOT EDIT (see note above)
    $ag-mat-grey-0: $mat-grey-0 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-grey-100") and not variable-exists("ag-mat-grey-100")) {
// DO NOT EDIT (see note above)
    $ag-mat-grey-100: $mat-grey-100 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-grey-200") and not variable-exists("ag-mat-grey-200")) {
// DO NOT EDIT (see note above)
    $ag-mat-grey-200: $mat-grey-200 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-grey-300") and not variable-exists("ag-mat-grey-300")) {
// DO NOT EDIT (see note above)
    $ag-mat-grey-300: $mat-grey-300 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-grey-50") and not variable-exists("ag-mat-grey-50")) {
// DO NOT EDIT (see note above)
    $ag-mat-grey-50: $mat-grey-50 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-indigo-50") and not variable-exists("ag-mat-indigo-50")) {
// DO NOT EDIT (see note above)
    $ag-mat-indigo-50: $mat-indigo-50 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-indigo-500") and not variable-exists("ag-mat-indigo-500")) {
// DO NOT EDIT (see note above)
    $ag-mat-indigo-500: $mat-indigo-500 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-pink-50") and not variable-exists("ag-mat-pink-50")) {
// DO NOT EDIT (see note above)
    $ag-mat-pink-50: $mat-pink-50 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("mat-pink-A200") and not variable-exists("ag-mat-pink-A200")) {
// DO NOT EDIT (see note above)
    $ag-mat-pink-A200: $mat-pink-A200 !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("panel-background-color") and not variable-exists("ag-panel-background-color")) {
// DO NOT EDIT (see note above)
    $ag-panel-background-color: $panel-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("params") and not variable-exists("ag-params")) {
// DO NOT EDIT (see note above)
    $ag-params: $params !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("primary-color") and not variable-exists("ag-primary-color")) {
// DO NOT EDIT (see note above)
    $ag-primary-color: $primary-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("range-selection-highlight-color") and not variable-exists("ag-range-selection-highlight-color")) {
// DO NOT EDIT (see note above)
    $ag-range-selection-highlight-color: $range-selection-highlight-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("secondary-foreground-color") and not variable-exists("ag-secondary-foreground-color")) {
// DO NOT EDIT (see note above)
    $ag-secondary-foreground-color: $secondary-foreground-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("selected-color") and not variable-exists("ag-selected-color")) {
// DO NOT EDIT (see note above)
    $ag-selected-color: $selected-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-delta-down-color") and not variable-exists("ag-value-change-delta-down-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-delta-down-color: $value-change-delta-down-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-delta-up-color") and not variable-exists("ag-value-change-delta-up-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-delta-up-color: $value-change-delta-up-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
@if (variable-exists("value-change-value-highlight-background-color") and not variable-exists("ag-value-change-value-highlight-background-color")) {
// DO NOT EDIT (see note above)
    $ag-value-change-value-highlight-background-color: $value-change-value-highlight-background-color !global;
// DO NOT EDIT (see note above)
}
// DO NOT EDIT (see note above)

// DO NOT EDIT (see note above)
// additional support for variables prefixed `ag-mat-` which was the original format for the material theme and is still supported
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-foreground-opacity) { $ag-foreground-opacity: $ag-mat-foreground-opacity !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary-foreground-color-opacity) { $ag-secondary-foreground-color-opacity: $ag-mat-secondary-foreground-color-opacity !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-disabled-foreground-color-opacity) { $ag-disabled-foreground-color-opacity: $ag-mat-disabled-foreground-color-opacity !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-grid-size) { $ag-grid-size: $ag-mat-grid-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-icon-size) { $ag-icon-size: $ag-mat-icon-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-header-height) { $ag-header-height: $ag-mat-header-height !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-row-height) { $ag-row-height: $ag-mat-row-height !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-cell-horizontal-padding) { $ag-cell-horizontal-padding: $ag-mat-cell-horizontal-padding !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-virtual-item-height) { $ag-virtual-item-height: $ag-mat-virtual-item-height !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-header-icon-size) { $ag-header-icon-size: $ag-mat-header-icon-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-family) { $ag-font-family: $ag-mat-font-family !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-size) { $ag-font-size: $ag-mat-font-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-weight) { $ag-font-weight: $ag-mat-font-weight !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary-font-family) { $ag-secondary-font-family: $ag-mat-secondary-font-family !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary-font-size) { $ag-secondary-font-size: $ag-mat-secondary-font-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary-font-weight) { $ag-secondary-font-weight: $ag-mat-secondary-font-weight !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-foreground-color) { $ag-foreground-color: $ag-mat-foreground-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary-foreground-color) { $ag-secondary-foreground-color: $ag-mat-secondary-foreground-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-disabled-foreground-color) { $ag-disabled-foreground-color: $ag-mat-disabled-foreground-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-border-color) { $ag-border-color: $ag-mat-border-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-primary-color) { $ag-primary-color: $ag-mat-primary-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-accent-color) { $ag-accent-color: $ag-mat-accent-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-icon-color) { $ag-icon-color: $ag-mat-icon-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-background-color) { $ag-background-color: $ag-mat-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-editor-background-color) { $ag-editor-background-color: $ag-mat-editor-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-panel-background-color) { $ag-panel-background-color: $ag-mat-panel-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-tool-panel-background-color) { $ag-tool-panel-background-color: $ag-mat-tool-panel-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-chip-background-color) { $ag-chip-background-color: $ag-mat-chip-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-range-selection-background-color) { $ag-range-selection-background-color: $ag-mat-range-selection-background-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-range-selection-highlight-color) { $ag-range-selection-highlight-color: $ag-mat-range-selection-highlight-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-hover-color) { $ag-hover-color: $ag-mat-hover-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-selected-color) { $ag-selected-color: $ag-mat-selected-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-cell-data-changed-color) { $ag-cell-data-changed-color: $ag-mat-cell-data-changed-color !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font) { $ag-font-family: $ag-mat-font !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-secondary) { $ag-secondary-font-family: $ag-mat-font-secondary !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-secondary-size) { $ag-secondary-font-size: $ag-mat-font-secondary-size !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-font-secondary-weight) { $ag-secondary-font-weight: $ag-mat-font-secondary-weight !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-primary) { $ag-primary-color: $ag-mat-primary !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-secondary) { $secondary-color: $ag-mat-secondary !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-foreground) { $ag-foreground-color: $ag-mat-foreground !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-foreground-secondary) { $ag-secondary-foreground-color: $ag-mat-foreground-secondary !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-foreground-disabled) { $ag-disabled-foreground-color: $ag-mat-foreground-disabled !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-background) { $ag-background-color: $ag-mat-background !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-background-editor) { $ag-editor-background-color: $ag-mat-background-editor !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-panel-background) { $ag-panel-background-color: $ag-mat-panel-background !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-tool-panel-background) { $ag-tool-panel-background-color: $ag-mat-tool-panel-background !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-chip-background) { $ag-chip-background-color: $ag-mat-chip-background !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-range-selection-background) { $ag-range-selection-background-color: $ag-mat-range-selection-background !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-range-selection-highlight) { $ag-range-selection-highlight-color: $ag-mat-range-selection-highlight !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-cell-data-changed) { $ag-cell-data-changed-color: $ag-mat-cell-data-changed !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-hover) { $ag-hover-color: $ag-mat-hover !global; }
// DO NOT EDIT (see note above)
@if variable-exists(ag-mat-selected) { $ag-selected-color: $ag-mat-selected !global; }
// DO NOT EDIT (see note above)
}