// ag-grid-react v27.3.0
import React from 'react';
import { HeaderFilterCellCtrl } from 'ag-grid-community';
declare const _default: React.MemoExoticComponent<(props: {
    ctrl: HeaderFilterCellCtrl;
}) => JSX.Element>;
export default _default;
