@import "../../ag-theme-classic/sass/ag-theme-classic";

// LEGACY THEME FILE
// Including this file emits CSS for the Blue theme. We no longer officially support this theme.
// See https://www.ag-grid.com/javascript-grid-themes-v23-migration/

@import "./legacy/ag-theme-blue-define-legacy-vars";

@include ag-theme-classic-impl("ag-theme-blue", (
    "foreground-color": #222,
    "background-color": #fff,
    "odd-row-background-color": #deebf7,
    "input-disabled-background-color": #dedede,
    "border-color": #9bc2e6,
    "cell-horizontal-border": dotted #9bc2e6,
    "header-background-color": #5e9cd3,
    "header-cell-moving-background-color": #9bc2e6,
    "header-foreground-color": #fff,
    "control-panel-background-color": #f6f6f6,
    "chip-background-color": #ddebf7,
    "range-selection-highlight-color": rgba(#8f8, 0.4),
    "value-change-delta-up-color": darkgreen,
    "value-change-delta-down-color": darkred,
    "value-change-value-highlight-background-color": #cec,
    "input-border-color": #000,
    "header-column-separator": true,
    "row-border-color": null,
    "row-hover-color": #f0f0f0,
    "column-hover-color": #f0f0f0,
    "subheader-background-color": #ececec,
));
