@import "../../ag-theme-classic/sass/ag-theme-classic";

// LEGACY THEME FILE
// Including this file emits CSS for the Dark theme. We no longer officially support this theme.
// See https://www.ag-grid.com/javascript-grid-themes-v23-migration/

@import "./legacy/ag-theme-dark-define-legacy-vars";

@include ag-theme-classic-impl("ag-theme-dark", (
    "foreground-color": #ccc,
    "background-color": #302e2e,
    "odd-row-background-color": #403e3e,
    "input-disabled-background-color": rgba(48, 46, 46, 0.3),
    "border-color": darkgrey,
    "cell-horizontal-border": dotted grey,
    "header-background-color": #626262,
    "header-cell-moving-background-color": #bebebe,
    "control-panel-background-color": #302e2e,
    "subheader-background-color": #201f1f,
    "chip-background-color": rgb(64, 62, 62),
    "range-selection-background-color": rgba(100, 160, 160, 0.4),
    "range-selection-highlight-color": rgba(255, 255, 255, 0.4),
    "value-change-delta-up-color": greenyellow,
    "value-change-delta-down-color": red,
    "value-change-value-highlight-background-color": chocolate,
    "input-border-color": #000,
    "header-column-separator": true,
    "row-border-color": null,
    "selected-row-background-color": #4a708b
));
