import { BeanStub } from "../../context/beanStub";
export declare class SetPinnedRightWidthFeature extends BeanStub {
    private pinnedWidthService;
    private element;
    constructor(element: HTMLElement);
    private postConstruct;
    private onPinnedRightWidthChanged;
}
