// ag-grid-react v27.3.0
import { Context } from 'ag-grid-community';
import React from 'react';
interface GridCompProps {
    context: Context;
}
declare const _default: React.MemoExoticComponent<({ context }: GridCompProps) => JSX.Element>;
export default _default;
