// ag-grid-react v27.3.0
import { CellCtrl } from 'ag-grid-community';
import React from 'react';
import { EditDetails } from './cellComp';
declare const _default: React.MemoExoticComponent<(props: {
    editDetails: EditDetails;
    cellCtrl: CellCtrl;
    eParentCell: HTMLElement;
    wrappedContent?: any;
    jsChildComp?: any;
}) => JSX.Element>;
export default _default;
