import { HeaderElement, XmlElement } from "../main";
export declare class XmlFactory {
    static createHeader(headerElement?: HeaderElement): string;
    static createXml(xmlElement: XmlElement, booleanTransformer?: (currentValue: boolean) => string): string;
    private static returnAttributeIfPopulated;
}
