export declare class Constants {
    static ROW_BUFFER_SIZE: number;
    static LAYOUT_INTERVAL: number;
    static BATCH_WAIT_MILLIS: number;
    static EXPORT_TYPE_DRAG_COPY: string;
    static EXPORT_TYPE_CLIPBOARD: string;
    static EXPORT_TYPE_EXCEL: string;
    static EXPORT_TYPE_CSV: string;
    static ROW_MODEL_TYPE_INFINITE: string;
    static ROW_MODEL_TYPE_VIEWPORT: string;
    static ROW_MODEL_TYPE_CLIENT_SIDE: string;
    static ROW_MODEL_TYPE_SERVER_SIDE: string;
    static ALWAYS: string;
    static ONLY_WHEN_GROUPING: string;
    static PINNED_TOP: string;
    static PINNED_BOTTOM: string;
    static DOM_LAYOUT_NORMAL: string;
    static DOM_LAYOUT_PRINT: string;
    static DOM_LAYOUT_AUTO_HEIGHT: string;
    static GROUP_AUTO_COLUMN_ID: string;
    static SOURCE_PASTE: string;
    static PINNED_RIGHT: 'right';
    static PINNED_LEFT: 'left';
    static SORT_ASC: 'asc';
    static SORT_DESC: 'desc';
    static INPUT_SELECTOR: string;
    static FOCUSABLE_SELECTOR: string;
    static FOCUSABLE_EXCLUDE: string;
}
