$ag-theme-{{theme}}-icon-font-family: "{{fontName}}";
$ag-theme-{{theme}}-icons-data: {{{src}}};
$ag-theme-{{theme}}-icons-font-codes: (
{{#each codepoints}}
    {{!
        workaround for Sass bug where unicode escapes are converted UTF8 characters
        https://stackoverflow.com/questions/30421570/sass-unicode-escape-is-not-preserved-in-css-file
        The effect of this is to ensure that our CSS files have escape sequences (e.g. "\f11d"),
        maintaining ASCII-compatibility and being more robust to character set encoding errors
    }}
    {{@key}}: unquote("\"\\") + unquote("{{this}}\""),
{{/each}}
);