@import "./ag-theme-base-mixin";

// LEGACY THEME FILE
// This mixin is for backwards compatibility with older apps that use global variables
// New apps should @import ag-theme-base-mixin.scss and @include ag-theme-base($params),
// instead of using this file.

@mixin ag-grid-theme {
    @include ag-theme-base(ag-theme-base-create-params-from-legacy-vars($ag-theme-base-default-params));
}
