import { BeanStub } from "../context/beanStub";
export declare class PaginationAutoPageSizeService extends BeanStub {
    private ctrlsService;
    private centerRowContainerCon;
    private postConstruct;
    private notActive;
    private onScrollVisibilityChanged;
    private onBodyHeightChanged;
    private checkPageSize;
}
