@import "../ag-theme-material-mixin";

// LEGACY THEME FILE
// This mixin is for backwards compatibility with older apps that use global variables
// Including this file emits CSS for the Material theme. New apps should @import ag-theme-material-mixin.scss
// and @include ag-theme-material($params), instead of using this file.

@import "./ag-theme-material-define-legacy-vars";

.ag-theme-material {
    @include ag-theme-material(ag-theme-base-create-params-from-legacy-vars($ag-theme-material-default-params));
    @include ag-v22-to-v23-compatibility-mode();
}
