// ag-grid-react v27.3.0
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var agGridReact_1 = require("./agGridReact");
exports.AgGridReact = agGridReact_1.AgGridReact;
var agGridReactLegacy_1 = require("./legacy/agGridReactLegacy");
exports.AgGridReactLegacy = agGridReactLegacy_1.AgGridReactLegacy;
var agGridReactUi_1 = require("./reactUi/agGridReactUi");
exports.AgGridReactFire = agGridReactUi_1.AgGridReactUi;
var agGridColumn_1 = require("./shared/agGridColumn");
exports.AgGridColumn = agGridColumn_1.AgGridColumn;
var changeDetectionService_1 = require("./shared/changeDetectionService");
exports.ChangeDetectionStrategyType = changeDetectionService_1.ChangeDetectionStrategyType;
