(window["observabilityDashboards_bundle_jsonpfunction"]=window["observabilityDashboards_bundle_jsonpfunction"]||[]).push([[17],{2339:function(module,__webpack_exports__,__webpack_require__){"use strict";__webpack_require__.r(__webpack_exports__);__webpack_require__.d(__webpack_exports__,"MarkdownSimple",(function(){return MarkdownSimple}));var react__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(0);var react__WEBPACK_IMPORTED_MODULE_0___default=__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);var react_markdown__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(2136);var react_markdown__WEBPACK_IMPORTED_MODULE_1___default=__webpack_require__.n(react_markdown__WEBPACK_IMPORTED_MODULE_1__);var markdownRenderers={root:react__WEBPACK_IMPORTED_MODULE_0__["Fragment"]};var MarkdownSimple=function MarkdownSimple(_ref){var children=_ref.children;return react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(react_markdown__WEBPACK_IMPORTED_MODULE_1___default.a,{renderers:markdownRenderers},children)};__webpack_exports__["default"]=MarkdownSimple}}]);