import React from "react";
interface Props {
    /**
     * The JavaScript code that we would like to execute.
     */
    data: string;
    /**
     * The media type associated with our component.
     */
    mediaType: "text/javascript";
}
export declare function runCodeHere(el: HTMLElement | null, code: string): any;
export declare class JavaScript extends React.PureComponent<Props> {
    static defaultProps: {
        data: string;
        mediaType: string;
    };
    el: HTMLElement | null;
    componentDidMount(): void;
    componentDidUpdate(): void;
    render(): JSX.Element;
}
export default JavaScript;
