import * as React from "react";
interface Props {
    data: string;
    mediaType: "text/latex";
}
export declare class LaTeX extends React.PureComponent<Props> {
    static defaultProps: {
        data: string;
        mediaType: string;
    };
    render(): JSX.Element;
}
export default LaTeX;
