@import "./ag-theme-alpine-dark-mixin";

// Including this file emits CSS for the Alpine Dark theme. If you want to extend the Alpine Dark theme,
// @import ag-theme-alpine-mixin.scss and @include ag-theme-alpine($params) instead of using this file.

.ag-theme-alpine-dark {
    @include ag-theme-alpine-dark($ag-theme-alpine-dark-default-params);
}
