export declare const MULTISELECT: string;
export declare const MULTISELECT_POPOVER: string;
export declare const MULTISELECT_TAG_INPUT_INPUT: string;
export declare const OMNIBAR: string;
export declare const OMNIBAR_OVERLAY: string;
export declare const SELECT: string;
export declare const SELECT_POPOVER: string;
export declare const SELECT_MATCH_TARGET_WIDTH: string;
