import React, { HTMLAttributes } from "react";
declare type LabelPlacement = "start" | "end";
interface Props extends HTMLAttributes<HTMLLabelElement> {
    label?: string;
    checked?: boolean;
    onChange?: () => void;
    labelPlacement?: LabelPlacement;
}
export declare const ToggleSwitch: React.FC<Props>;
export {};
