// ag-grid-react v27.3.0
import { RowContainerName } from 'ag-grid-community';
import React from 'react';
declare const _default: React.MemoExoticComponent<(params: {
    name: RowContainerName;
}) => JSX.Element>;
export default _default;
