@import "../../ag-theme-balham/sass/ag-theme-balham-mixin";
@import "./ag-theme-balham-dark-default-params";

@mixin ag-theme-balham-dark($params: ()) {
    $params: ag-process-theme-variables($params, $ag-theme-balham-dark-default-params);
    color-scheme: dark;
    @include ag-theme-balham($params);

    .ag-tooltip {
        background-color: #1c1f20;
    }
}