@import "./ag-theme-base-rename-legacy-vars";

// In v23 we moved from using global variables to maps of parameters to configure Grid themes.
// This file is part of a backwards-compatibility layer designed to emulate the pre-v23 behaviour
// and so should not be modified.

// DO NOT EDIT (see note above)
$ag-foreground-opacity: 1 !default;
// DO NOT EDIT (see note above)
$ag-secondary-foreground-color-opacity: 1 !default;
// DO NOT EDIT (see note above)
$ag-disabled-foreground-color-opacity: 0.5 !default;
// DO NOT EDIT (see note above)
$ag-border-color: transparent !default;
// DO NOT EDIT (see note above)
$ag-background-color: #fff !default;
// DO NOT EDIT (see note above)
$ag-foreground-color: #000 !default;
// DO NOT EDIT (see note above)
$ag-header-background-color: $ag-background-color !default;
// DO NOT EDIT (see note above)
$ag-header-foreground-color: $ag-foreground-color !default;
// DO NOT EDIT (see note above)
$ag-icon-color: lightgray !default;
// DO NOT EDIT (see note above)
$ag-alt-icon-color: $ag-background-color !default;
// DO NOT EDIT (see note above)
$ag-accent-color: transparent !default;
// DO NOT EDIT (see note above)
$ag-primary-color: transparent !default;
// DO NOT EDIT (see note above)
$ag-selected-color: null !default;
// DO NOT EDIT (see note above)
$ag-hover-color: null !default;
// DO NOT EDIT (see note above)
$ag-header-cell-hover-background-color: null !default;
// DO NOT EDIT (see note above)
$ag-range-selection-highlight-color: null !default;
// DO NOT EDIT (see note above)
$ag-odd-row-background-color: null !default;
// DO NOT EDIT (see note above)
$ag-value-change-value-highlight-background-color: null !default;
// DO NOT EDIT (see note above)
$ag-value-change-delta-up-color: null !default;
// DO NOT EDIT (see note above)
$ag-value-change-delta-down-color: null !default;
// DO NOT EDIT (see note above)
$ag-chip-background-color: null !default;
// DO NOT EDIT (see note above)
$ag-range-selection-background-color: $ag-icon-color !default;
// DO NOT EDIT (see note above)
$ag-grid-size: 4px !default;
// DO NOT EDIT (see note above)
$ag-icon-size: 12px !default;
// DO NOT EDIT (see note above)
$ag-header-height: $ag-grid-size * 6 + 1 !default;
// DO NOT EDIT (see note above)
$ag-row-height: ($ag-grid-size * 6 + 1) !default;
// DO NOT EDIT (see note above)
$ag-cell-horizontal-padding: $ag-grid-size * 3 !default;
// DO NOT EDIT (see note above)
$ag-virtual-item-height: $ag-grid-size * 5 !default;
// DO NOT EDIT (see note above)
$ag-rich-select-item-height: $ag-virtual-item-height !default;
// DO NOT EDIT (see note above)
$ag-header-icon-size: 14px !default;
// DO NOT EDIT (see note above)
$ag-font-family: 'Helvetica Neue', sans-serif !default;
// DO NOT EDIT (see note above)
$ag-font-size: 14px !default;
// DO NOT EDIT (see note above)
$ag-font-weight: 400 !default;
// DO NOT EDIT (see note above)
$ag-secondary-font-family: $ag-font-family !default;
// DO NOT EDIT (see note above)
$ag-secondary-font-size: 14px !default;
// DO NOT EDIT (see note above)
$ag-secondary-font-weight: 400 !default;
// DO NOT EDIT (see note above)
$ag-secondary-foreground-color: $ag-foreground-color !default;
// DO NOT EDIT (see note above)
$ag-tooltip-background-color: $ag-background-color !default;
// DO NOT EDIT (see note above)
$ag-tooltip-foreground-color: $ag-foreground-color !default;
// DO NOT EDIT (see note above)
$ag-tooltip-border-radius: 2px !default;
// DO NOT EDIT (see note above)
$ag-tooltip-padding: 5px !default;
// DO NOT EDIT (see note above)
$ag-tooltip-border-width: 1px !default;
// DO NOT EDIT (see note above)
$ag-tooltip-border-style: solid !default;
// DO NOT EDIT (see note above)
$ag-tooltip-border-color: #ebebeb !default;
// DO NOT EDIT (see note above)
$ag-card-shadow: none !default;
// DO NOT EDIT (see note above)
$ag-card-radius: 0 !default;
// DO NOT EDIT (see note above)
$ag-row-border-width: 0 !default;
// DO NOT EDIT (see note above)
$ag-transition-speed: 120ms !default;
// DO NOT EDIT (see note above)
$ag-cell-horizontal-border: 1px solid transparent !default;
// DO NOT EDIT (see note above)
$ag-toolpanel-indent-size: $ag-grid-size + $ag-icon-size !default;
// DO NOT EDIT (see note above)
$ag-row-group-indent-size: $ag-grid-size * 3 + $ag-icon-size !default;
// DO NOT EDIT (see note above)
$ag-header-cell-moving-background-color: rgb(190, 190, 190) !default;
// DO NOT EDIT (see note above)
$ag-input-disabled-background-color: #ebebeb !default;
// DO NOT EDIT (see note above)
$ag-input-border-color: #000000 !default;
// DO NOT EDIT (see note above)
$ag-dialog-background-color: $ag-background-color !default;
// DO NOT EDIT (see note above)
$ag-dialog-border-size: 1px !default;
// DO NOT EDIT (see note above)
$ag-dialog-border-style: solid !default;
// DO NOT EDIT (see note above)
$ag-dialog-border-color: $ag-border-color !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-background-color: $ag-header-background-color !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-foreground-color: $ag-header-foreground-color !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-height: $ag-header-height !default;
// DO NOT EDIT (see note above)
@import "../ag-theme-base-font-vars";
// DO NOT EDIT (see note above)
$ag-dialog-title-font-family: $ag-secondary-font-family !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-font-size: $ag-secondary-font-size !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-font-weight: $ag-secondary-font-weight !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-padding: 5px 10px !default;
// DO NOT EDIT (see note above)
$ag-dialog-title-icon-size: max(20px, $ag-icon-size) !default;
// DO NOT EDIT (see note above)
$ag-tool-panel-background-color: $ag-background-color !default;
// DO NOT EDIT (see note above)
$ag-group-component-background-color: lighten($ag-tool-panel-background-color, 1%) !default;
// DO NOT EDIT (see note above)
$ag-group-component-border-color: lighten($ag-border-color, 5%) !default;
// DO NOT EDIT (see note above)
$ag-group-component-title-background-color: darken($ag-group-component-background-color, 5%) !default;
// DO NOT EDIT (see note above)
$ag-range-selection-chart-background-color: adjust-hue($ag-range-selection-background-color, 25deg) !default;
// DO NOT EDIT (see note above)
$ag-range-selection-chart-category-background-color: adjust-hue($ag-range-selection-background-color, -80deg) !default;
// DO NOT EDIT (see note above)
$ag-full-width-tabs: false !default;
// DO NOT EDIT (see note above)
$ag-icon-font-family: $ag-theme-base-icon-font-family !default;
// DO NOT EDIT (see note above)
$ag-icons-data: $ag-theme-base-icons-data !default;
// DO NOT EDIT (see note above)
$ag-icons-font-codes: $ag-theme-base-icons-font-codes !default;
// DO NOT EDIT (see note above)
$ag-icon-aggregation: map-get($ag-icons-font-codes, "aggregation") !default;
// DO NOT EDIT (see note above)
$ag-icon-arrows: map-get($ag-icons-font-codes, "arrows") !default;
// DO NOT EDIT (see note above)
$ag-icon-asc: map-get($ag-icons-font-codes, "asc") !default;
// DO NOT EDIT (see note above)
$ag-icon-cancel: map-get($ag-icons-font-codes, "cancel") !default;
// DO NOT EDIT (see note above)
$ag-icon-chart: map-get($ag-icons-font-codes, "chart") !default;
// DO NOT EDIT (see note above)
$ag-icon-checkbox-checked: map-get($ag-icons-font-codes, "checkbox-checked") !default;
// DO NOT EDIT (see note above)
$ag-icon-checkbox-indeterminate: map-get($ag-icons-font-codes, "checkbox-indeterminate") !default;
// DO NOT EDIT (see note above)
$ag-icon-checkbox-unchecked: map-get($ag-icons-font-codes, "checkbox-unchecked") !default;
// DO NOT EDIT (see note above)
$ag-icon-color-picker: map-get($ag-icons-font-codes, "color-picker") !default;
// DO NOT EDIT (see note above)
$ag-icon-column: map-get($ag-icons-font-codes, "column") !default;
// DO NOT EDIT (see note above)
$ag-icon-columns: map-get($ag-icons-font-codes, "columns") !default;
// DO NOT EDIT (see note above)
$ag-icon-contracted: map-get($ag-icons-font-codes, "contracted") !default;
// DO NOT EDIT (see note above)
$ag-icon-copy: map-get($ag-icons-font-codes, "copy") !default;
// DO NOT EDIT (see note above)
$ag-icon-cross: map-get($ag-icons-font-codes, "cross") !default;
// DO NOT EDIT (see note above)
$ag-icon-cut: map-get($ag-icons-font-codes, "cut") !default;
// DO NOT EDIT (see note above)
$ag-icon-data: map-get($ag-icons-font-codes, "data") !default;
// DO NOT EDIT (see note above)
$ag-icon-desc: map-get($ag-icons-font-codes, "desc") !default;
// DO NOT EDIT (see note above)
$ag-icon-expanded: map-get($ag-icons-font-codes, "expanded") !default;
// DO NOT EDIT (see note above)
$ag-icon-eye-slash: map-get($ag-icons-font-codes, "eye-slash") !default;
// DO NOT EDIT (see note above)
$ag-icon-eye: map-get($ag-icons-font-codes, "eye") !default;
// DO NOT EDIT (see note above)
$ag-icon-filter: map-get($ag-icons-font-codes, "filter") !default;
// DO NOT EDIT (see note above)
$ag-icon-first: map-get($ag-icons-font-codes, "first") !default;
// DO NOT EDIT (see note above)
$ag-icon-grip: map-get($ag-icons-font-codes, "grip") !default;
// DO NOT EDIT (see note above)
$ag-icon-group: map-get($ag-icons-font-codes, "group") !default;
// DO NOT EDIT (see note above)
$ag-icon-indeterminate: map-get($ag-icons-font-codes, "indeterminate") !default;
// DO NOT EDIT (see note above)
$ag-icon-last: map-get($ag-icons-font-codes, "last") !default;
// DO NOT EDIT (see note above)
$ag-icon-left: map-get($ag-icons-font-codes, "left") !default;
// DO NOT EDIT (see note above)
$ag-icon-linked: map-get($ag-icons-font-codes, "linked") !default;
// DO NOT EDIT (see note above)
$ag-icon-loading: map-get($ag-icons-font-codes, "loading") !default;
// DO NOT EDIT (see note above)
$ag-icon-maximize: map-get($ag-icons-font-codes, "maximize") !default;
// DO NOT EDIT (see note above)
$ag-icon-menu: map-get($ag-icons-font-codes, "menu") !default;
// DO NOT EDIT (see note above)
$ag-icon-minimize: map-get($ag-icons-font-codes, "minimize") !default;
// DO NOT EDIT (see note above)
$ag-icon-minus: map-get($ag-icons-font-codes, "minus") !default;
// DO NOT EDIT (see note above)
$ag-icon-next: map-get($ag-icons-font-codes, "next") !default;
// DO NOT EDIT (see note above)
$ag-icon-none: map-get($ag-icons-font-codes, "none") !default;
// DO NOT EDIT (see note above)
$ag-icon-not-allowed: map-get($ag-icons-font-codes, "not-allowed") !default;
// DO NOT EDIT (see note above)
$ag-icon-paste: map-get($ag-icons-font-codes, "paste") !default;
// DO NOT EDIT (see note above)
$ag-icon-pin: map-get($ag-icons-font-codes, "pin") !default;
// DO NOT EDIT (see note above)
$ag-icon-pivot: map-get($ag-icons-font-codes, "pivot") !default;
// DO NOT EDIT (see note above)
$ag-icon-plus: map-get($ag-icons-font-codes, "plus") !default;
// DO NOT EDIT (see note above)
$ag-icon-previous: map-get($ag-icons-font-codes, "previous") !default;
// DO NOT EDIT (see note above)
$ag-icon-radio-button-off: map-get($ag-icons-font-codes, "radio-button-off") !default;
// DO NOT EDIT (see note above)
$ag-icon-radio-button-on: map-get($ag-icons-font-codes, "radio-button-on") !default;
// DO NOT EDIT (see note above)
$ag-icon-right: map-get($ag-icons-font-codes, "right") !default;
// DO NOT EDIT (see note above)
$ag-icon-save: map-get($ag-icons-font-codes, "save") !default;
// DO NOT EDIT (see note above)
$ag-icon-small-down: map-get($ag-icons-font-codes, "small-down") !default;
// DO NOT EDIT (see note above)
$ag-icon-small-left: map-get($ag-icons-font-codes, "small-left") !default;
// DO NOT EDIT (see note above)
$ag-icon-small-right: map-get($ag-icons-font-codes, "small-right") !default;
// DO NOT EDIT (see note above)
$ag-icon-small-up: map-get($ag-icons-font-codes, "small-up") !default;
// DO NOT EDIT (see note above)
$ag-icon-tick: map-get($ag-icons-font-codes, "tick") !default;
// DO NOT EDIT (see note above)
$ag-icon-tree-closed: map-get($ag-icons-font-codes, "tree-closed") !default;
// DO NOT EDIT (see note above)
$ag-icon-tree-indeterminate: map-get($ag-icons-font-codes, "tree-indeterminate") !default;
// DO NOT EDIT (see note above)
$ag-icon-tree-open: map-get($ag-icons-font-codes, "tree-open") !default;
// DO NOT EDIT (see note above)
$ag-icon-unlinked: map-get($ag-icons-font-codes, "unlinked") !default;