import * as React from "react";
interface Props {
    data: object;
    mediaType: "application/json";
    theme: string;
    metadata: {
        expanded: boolean;
    };
}
/** @component */
export declare class Json extends React.PureComponent<Props> {
    static defaultProps: {
        data: null;
        mediaType: string;
        theme: string;
        metadata: {
            expanded: boolean;
        };
    };
    shouldExpandNode: () => boolean;
    render(): JSX.Element;
}
export default Json;
